from setuptools import setup

setup(name='llu_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['llu_distributions'],
	  author='Leqi Lu',
	  author_email='leqilu67@gmail.com',
	  zip_safe=False)
